@@ -1,10 +1,15 @@
-
 class NoDataException(Exception):
     pass
 
 
+class RaceCancelledException(Exception):
+    def __init__(self, msg=None):
+        super().__init__(msg)
+
+
 class UnableActionException(Exception):
-    pass
+    def __init__(self, msg=None):
+        super().__init__(msg)
 
 
 class LoginFailException(Exception):
